@@ -3,16 +3,18 @@ from unittest.mock import MagicMock, patch
 from . import run_vulnerability_scan
 from aikido_zen.context import current_context, Context
 from aikido_zen.errors import AikidoSQLInjection
-from aikido_zen.thread.thread_cache import ThreadCache, threadlocal_storage
+from aikido_zen.thread.thread_cache import get_cache
+from aikido_zen.helpers.iplist import IPList
 
 
 @pytest.fixture(autouse=True)
 def run_around_tests():
+    get_cache().reset()
     yield
     # Make sure to reset context and cache after every test so it does not
     # interfere with other tests
     current_context.set(None)
-    setattr(threadlocal_storage, "cache", None)
+    get_cache().reset()
 
 
 @pytest.fixture
@@ -48,14 +50,14 @@ def get_context():
 
 def test_run_vulnerability_scan_no_context(caplog):
     current_context.set(None)
-    threadlocal_storage.cache = 1
+    get_cache().cache = 1
     run_vulnerability_scan(kind="test", op="test", args=tuple())
     assert len(caplog.text) == 0
 
 
 def test_run_vulnerability_scan_no_context_no_lifecycle(caplog):
     current_context.set(None)
-    threadlocal_storage.cache = None
+    get_cache().cache = None
     run_vulnerability_scan(kind="test", op="test", args=tuple())
     assert len(caplog.text) == 0
 
@@ -63,13 +65,12 @@ def test_run_vulnerability_scan_no_context_no_lifecycle(caplog):
 def test_run_vulnerability_scan_context_no_lifecycle(caplog):
     with pytest.raises(Exception):
         current_context.set(1)
-        threadlocal_storage.cache = None
+        get_cache().cache = None
         run_vulnerability_scan(kind="test", op="test", args=tuple())
 
 
 def test_lifecycle_cache_ok(caplog, get_context):
     get_context.set_as_current_context()
-    cache = ThreadCache()
     run_vulnerability_scan(kind="test", op="test", args=tuple())
     assert "Vulnerability type test currently has no scans implemented" in caplog.text
 
@@ -81,8 +82,9 @@ def test_ssrf(caplog, get_context):
 
 def test_lifecycle_cache_bypassed_ip(caplog, get_context):
     get_context.set_as_current_context()
-    cache = ThreadCache()
-    cache.config.bypassed_ips = {"198.51.100.23"}
+    cache = get_cache()
+    cache.config.bypassed_ips = IPList()
+    cache.config.bypassed_ips.add("198.51.100.23")
     assert cache.is_bypassed_ip("198.51.100.23")
     run_vulnerability_scan(kind="test", op="test", args=tuple())
     assert len(caplog.text) == 0
@@ -90,19 +92,35 @@ def test_lifecycle_cache_bypassed_ip(caplog, get_context):
 
 def test_sql_injection(caplog, get_context, monkeypatch):
     get_context.set_as_current_context()
-    cache = ThreadCache()
     monkeypatch.setenv("AIKIDO_BLOCK", "1")
+
+    assert get_cache().stats.get_record()["requests"]["attacksDetected"]["total"] == 0
     with pytest.raises(AikidoSQLInjection):
         run_vulnerability_scan(
             kind="sql_injection",
             op="test_op",
             args=("INSERT * INTO VALUES ('doggoss2', TRUE);", "mysql"),
         )
+    assert get_cache().stats.get_record()["requests"]["attacksDetected"]["total"] == 1
+    assert get_cache().stats.get_record()["requests"]["attacksDetected"]["blocked"] == 1
+
+
+def test_sql_injection_but_blocking_off(caplog, get_context, monkeypatch):
+    get_context.set_as_current_context()
+    monkeypatch.setenv("AIKIDO_BLOCK", "0")
+
+    assert get_cache().stats.get_record()["requests"]["attacksDetected"]["total"] == 0
+    run_vulnerability_scan(
+        kind="sql_injection",
+        op="test_op",
+        args=("INSERT * INTO VALUES ('doggoss2', TRUE);", "mysql"),
+    )
+    assert get_cache().stats.get_record()["requests"]["attacksDetected"]["total"] == 1
+    assert get_cache().stats.get_record()["requests"]["attacksDetected"]["blocked"] == 0
 
 
 def test_sql_injection_with_route_params(caplog, get_context, monkeypatch):
     get_context.set_as_current_context()
-    cache = ThreadCache()
     monkeypatch.setenv("AIKIDO_BLOCK", "1")
     with pytest.raises(AikidoSQLInjection):
         run_vulnerability_scan(
@@ -114,8 +132,6 @@ def test_sql_injection_with_route_params(caplog, get_context, monkeypatch):
 
 def test_sql_injection_with_comms(caplog, get_context, monkeypatch):
     get_context.set_as_current_context()
-    cache = ThreadCache()
-    cache.last_renewal = 9999999999999999999999
     monkeypatch.setenv("AIKIDO_BLOCK", "1")
     with patch("aikido_zen.background_process.comms.get_comms") as mock_get_comms:
         # Create a mock comms object
@@ -135,20 +151,54 @@ def test_sql_injection_with_comms(caplog, get_context, monkeypatch):
             call_args[1][0]["metadata"]["sql"]
             == "INSERT * INTO VALUES ('doggoss2', TRUE);"
         )
+        assert call_args[1][0]["metadata"]["dialect"] == "mysql"
 
 
-def test_ssrf_with_comms_hostnames_add(caplog, get_context, monkeypatch):
+def test_ssrf_vulnerability_scan_adds_hostname(get_context):
     get_context.set_as_current_context()
-    monkeypatch.setenv("AIKIDO_BLOCK", "1")
-    with patch("aikido_zen.background_process.comms.get_comms") as mock_get_comms:
-        # Create a mock comms object
-        mock_comms = MagicMock()
-        mock_get_comms.return_value = mock_comms  # Set the return value of get_comms
-        run_vulnerability_scan(
-            kind="ssrf",
-            op="test_op",
-            args=([], "test-hostname", 8097),
-        )
-        mock_comms.send_data_to_bg_process.assert_any_call(
-            "HOSTNAMES_ADD", ("test-hostname", 8097)
-        )
+
+    dns_results = MagicMock()
+    hostname = "example.com"
+    port = 80
+
+    run_vulnerability_scan(kind="ssrf", op="test", args=(dns_results, hostname, port))
+
+    # Verify that hostnames.add was called with the correct arguments
+    assert get_cache().hostnames.as_array() == [
+        {"hits": 1, "hostname": "example.com", "port": 80}
+    ]
+    run_vulnerability_scan(kind="ssrf", op="test", args=(dns_results, hostname, port))
+    assert get_cache().hostnames.as_array() == [
+        {"hits": 2, "hostname": "example.com", "port": 80}
+    ]
+
+
+def test_ssrf_vulnerability_scan_no_port(get_context):
+    get_context.set_as_current_context()
+
+    dns_results = MagicMock()
+    hostname = "example.com"
+    port = 0  # Port is zero, should not add to hostnames
+
+    assert get_cache().stats.get_record()["requests"]["attacksDetected"]["total"] == 0
+    run_vulnerability_scan(kind="ssrf", op="test", args=(dns_results, hostname, port))
+    assert get_cache().stats.get_record()["requests"]["attacksDetected"]["total"] == 0
+
+    assert get_cache().hostnames.as_array() == []
+
+
+def test_ssrf_vulnerability_scan_bypassed_ip(get_context):
+    get_context.set_as_current_context()
+    get_cache().config.bypassed_ips = IPList()
+    get_cache().config.bypassed_ips.add("198.51.100.23")
+
+    dns_results = MagicMock()
+    hostname = "example.com"
+    port = 80
+
+    assert get_cache().stats.get_record()["requests"]["attacksDetected"]["total"] == 0
+    run_vulnerability_scan(kind="ssrf", op="test", args=(dns_results, hostname, port))
+    assert get_cache().stats.get_record()["requests"]["attacksDetected"]["total"] == 0
+
+    # Verify that hostnames.add was not called due to bypassed IP
+    assert get_cache().hostnames.as_array() == []
